@@ -7,13 +7,15 @@ from blueflask.lib.errors import internal_error, bad_request, not_found
 
 from blueflask.lib.infos import success
 
-from ...consts import CONFIG, SERVICE_CODE, LOGS
+from ...consts import CONFIG, SERVICE_CODE, LOGS, OPEN_VOX
 from . import api
 from ... import getsms as lib_customer
 
 
 import json
 import pika
+import requests
+import time
 
 
 @api.route('/sms', methods=['POST'])
