@@ -38,6 +38,11 @@ SMPP_ACCOUNTS = [
     if i.startswith('SMPP_')
     ]
 
+OPEN_VOX = {
+    'url': CONFIG['OPEN_VOX']['url'],
+    'user': CONFIG['OPEN_VOX']['user'],
+    'pwd': CONFIG['OPEN_VOX']['pwd']
+}
 LOG_LEVEL = CONFIG['LOGS']['level']
 LOG_FILE = CONFIG['LOGS']['filename']
 
