@@ -110,7 +110,7 @@ class Getsms(object):
             message = re.findall(
                     r"[A-Za-z0-9 \\r\\nÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖØŒŠþ"
                     "ÙÚÛÜÝŸàáâãäåæçèéêëìíîïðñòóôõöøœšÞùúûüýÿ!\"#$%"
-                    "&'()+,\-./:;<=>?¡¿^{}\\\[~\]|\u20AC]+", message
+                    "&'()+,\\-./:;<=>?¡¿^{}\\\\[~\\]|\u20AC]+", message
                     )
             message = ''.join(message)
             kwargs = {
@@ -187,10 +187,10 @@ class Getsms(object):
             )
         return url
 
-    def chunks(self, l, n):
+    def chunks(self, list_l, n):
         if n < 1:
             n = 1
-        return [l[i:i + n] for i in range(0, len(l), n)]
+        return [list_l[i:i + n] for i in range(0, len(list_l), n)]
 
     def gsm_decode(self, hexstr):
         hexparts = self.chunks(hexstr, 2)
